@@ -188,7 +188,9 @@ class PostgresqlOpTest(TestBase):
     def test_col_w_pk_is_serial(self):
         context = op_fixture("postgresql")
         op.add_column("some_table", Column("q", Integer, primary_key=True))
-        context.assert_("ALTER TABLE some_table ADD COLUMN q SERIAL NOT NULL")
+        context.assert_(
+            "ALTER TABLE some_table ADD COLUMN q SERIAL NOT NULL PRIMARY KEY"
+        )
 
     def test_create_exclude_constraint(self):
         context = op_fixture("postgresql")
